@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.518 2014/09/25 05:12:09 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.526 2014/11/26 05:18:52 zender Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
@@ -150,6 +150,9 @@ extern "C" {
      NCO uses netCDF token DEFAULT_CHUNK_SIZE and default algorithm when user specifies no  chunking option */
 #define NCO_CNK_SZ_BYT_DFL 4194304
 
+  /* 20141105 Minimum size of a variable to chunk */
+#define NCO_CNK_SZ_MIN_BYT_DFL 8192
+
   /* Linux default blocksize is 4096 B---a good chunk size for 1-D record dimension variables */
 #define NCO_CNK_SZ_BYT_R1D_DFL 4096
 
@@ -249,17 +252,46 @@ extern "C" {
   /* 20140924: netCDF meta-information available in library versions 4.3.3-rc2 
      Define compatibility tokens for earlier libraries equivalent to 3.6.0 */
 #ifndef NC_VERSION_MAJOR
- #define NC_VERSION_MAJOR 3
+# define NC_VERSION_MAJOR 3
 #endif /* !NC_VERSION_MAJOR */
 #ifndef NC_VERSION_MINOR
- #define NC_VERSION_MINOR 6
+# define NC_VERSION_MINOR 6
 #endif /* !NC_VERSION_MINOR */
 #ifndef NC_VERSION_PATCH
- #define NC_VERSION_PATCH 0
+# define NC_VERSION_PATCH 0
 #endif /* !NC_VERSION_PATCH */
-#ifndef NCO_NC_LIB_VERSION
-# define NCO_NC_LIB_VERSION ( NC_VERSION_MAJOR * 100 + NC_VERSION_MINOR * 10 + NC_VERSION_PATCH )
-#endif /* !NCO_NC_LIB_VERSION */
+#ifndef NC_VERSION_NOTE
+# define NC_VERSION_NOTE  "" /* My be blank */
+#endif /* !NC_VERSION_NOTE */
+#ifndef NC_VERSION
+# define NC_VERSION "3.6.0"
+#endif /* !NC_VERSION */
+  /* Define NC_LIB_VERSION as three-digit number for arithmetic comparisons by CPP */
+#ifndef NC_LIB_VERSION
+# define NC_LIB_VERSION ( NC_VERSION_MAJOR * 100 + NC_VERSION_MINOR * 10 + NC_VERSION_PATCH )
+#endif /* !NC_LIB_VERSION */
+
+  /* NCO meta-information available in VERSION token since forever
+     20141008: Define NCO tokens consistent with new netcdf_meta.h tokens */
+#ifndef NCO_VERSION_MAJOR
+# define NCO_VERSION_MAJOR 4
+#endif /* !NCO_VERSION_MAJOR */
+#ifndef NCO_VERSION_MINOR
+# define NCO_VERSION_MINOR 4
+#endif /* !NCO_VERSION_MINOR */
+#ifndef NCO_VERSION_PATCH
+# define NCO_VERSION_PATCH 7
+#endif /* !NCO_VERSION_PATCH */
+#ifndef NCO_VERSION_NOTE
+# define NCO_VERSION_NOTE  "" /* My be blank */
+#endif /* !NCO_VERSION_NOTE */
+#ifndef NCO_LIB_VERSION
+  /* Define NC_LIB_VERSION as three-digit number for arithmetic comparisons by CPP */
+# define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
+#endif /* !NCO_LIB_VERSION */
+#ifndef NCO_VERSION
+# define NCO_VERSION "4.4.7"
+#endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
 #ifndef NC_NETCDF4
@@ -467,20 +499,20 @@ extern "C" {
 #define TRV_MAP_SIZE NC_MAX_DIMS
 
   enum nco_prg_id{ /* [enm] Key value for all netCDF operators */
-    ncap,
-    ncatted,
-    ncbo,
-    ncfe, 
-    ncecat,
-    ncflint,
-    ncks,
-    ncpdq,
-    ncra,
-    ncrcat,
-    ncrename,
-    ncwa,
-    ncge, /* 20131018: New operator */
-    ncmv /* 20131018: Potential new operator */
+    ncap, /* 0 [enm] */
+    ncatted, /* 1 [enm] */
+    ncbo, /* 2 [enm] */
+    ncfe, /* 3 [enm] */
+    ncecat, /* 4 [enm] */
+    ncflint, /* 5 [enm] */
+    ncks, /* 6 [enm] */
+    ncpdq, /* 7 [enm] */
+    ncra, /* 8 [enm] */
+    ncrcat, /* 9 [enm] */
+    ncrename, /* 10 [enm] */
+    ncwa, /* 11 [enm] */
+    ncge, /* 12 [enm] */ /* 20131018: New operator */
+    ncmv /* 13 [enm] */ /* 20131018: Potential new operator */
   }; /* end nco_prg_id enum */
   
   enum nco_dbg_typ_enm{ /* [enm] Debugging levels */
@@ -488,7 +520,7 @@ extern "C" {
     nco_dbg_quiet, /* 0 [enm] Quiet all non-error messages */
     nco_dbg_std,   /* 1 [enm] Standard mode. Minimal, but some, messages */
     nco_dbg_fl,    /* 2 [enm] Filenames */
-    nco_dbg_scl,   /* 3 [enm] Scalars, other per-file information  */
+    nco_dbg_scl,   /* 3 [enm] Scalars, other per-file information */
     nco_dbg_grp,   /* 4 [enm] Groups, highest level per-file loop information */
     nco_dbg_var,   /* 5 [enm] Variables, highest level per-group loop information */
     nco_dbg_crr,   /* 6 [enm] Current task */
@@ -848,8 +880,9 @@ extern "C" {
     cnk_dmn_sct **cnk_dmn; /* [sct] User-specified per-dimension chunking information */
     int cnk_map; /* [enm] Chunking map */
     int cnk_plc; /* [enm] Chunking policy */
-    size_t cnk_sz_scl; /* [nbr] Chunk size scalar */
+    size_t cnk_min_byt; /* [B] Minimize size of variable to chunk */
     size_t cnk_sz_byt; /* [B] Chunk size in Bytes */
+    size_t cnk_sz_scl; /* [nbr] Chunk size scalar */
   } cnk_sct;
   
   /* GTT structure to break full path name into components */
@@ -1155,15 +1188,15 @@ extern "C" {
   } var_sct; /* end var_sct_tag */
 
    /* Dimension utility structure to share common fields; used in nco_cnk_sz_set_trv() */
-  typedef struct{ 
-    char nm[NC_MAX_NAME+1L];/* [sng] Name of dimension/coordinate */
+  typedef struct{
     char *nm_fll; /* [sng] Full dimension name */
-    nco_bool is_rec_dmn; /* [flg] Is a record dimension/coordinate? */
-    size_t sz; /* [nbr] Size of dimension/coordinate */
+    char nm[NC_MAX_NAME+1L];/* [sng] Name of dimension/coordinate */
+    int id; /* [id] Dimension ID */
     nco_bool NON_HYP_DMN; /* [flg] Limit is same as dimension in input file */
-    size_t dmn_cnt; /* [nbr] Hyperslabbed size of dimension */ 
-    int id; /* [id] Dimension ID */ 
-  } dmn_cmn_sct; 
+    nco_bool is_rec_dmn; /* [flg] Dimension is unlimited/record dimension */
+    size_t dmn_cnt; /* [nbr] Hyperslabbed size of dimension (= sz iff !NON_HYP_DMN) */
+    size_t sz; /* [nbr] Size (non-hyperslabbed) of dimension */
+  } dmn_cmn_sct;
 
 #ifdef __cplusplus
 } /* end extern "C" */
