@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnf_typ.c,v 1.77 2014/06/15 21:06:22 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnf_typ.c,v 1.80 2014/09/30 23:03:29 zender Exp $ */
 
 /* Purpose: Conform variable types */
 
@@ -104,7 +104,7 @@ cast_nctype_void /* [fnc] Cast generic pointer in ptr_unn structure from type ty
 } /* end cast_nctype_void() */
 
 var_sct * /* O [var] Variable after (possible) conversion */
-nco_typ_cnv_rth  /* [fnc] Convert char, short, long, int types to doubles before arithmetic */
+nco_typ_cnv_rth /* [fnc] Convert char, short, long, int, and float types to doubles before arithmetic */
 (var_sct *var, /* I/O [var] Variable to be considered for conversion */
  const int nco_op_typ) /* I [enm] Operation type */
 {
@@ -131,7 +131,8 @@ nco_typ_cnv_rth  /* [fnc] Convert char, short, long, int types to doubles before
      Implementing --dbl switch on ncwa, ncra, nces (ncap2?) to force implicit conversion */
   if(nco_rth_cnv_get() == nco_rth_flt_flt){
 
-    /* Traditional NCO convention: promote, where necessary, anything but floats and doubles */
+    /* NCO default until 201309: promote, where necessary, anything but floats and doubles
+       Now non-default and activated only by --flt switch */
     if(var->typ_upk == NC_FLOAT){
       var=nco_var_cnf_typ((nc_type)NC_FLOAT,var);
     }else{ /* Conversion only for appropriate operation types */ 
@@ -140,7 +141,8 @@ nco_typ_cnv_rth  /* [fnc] Convert char, short, long, int types to doubles before
 
   }else{ /* !nco_rth_flt_flt */
 
-    /* User-specified new convention: promote, where necessary, anything but doubles */
+    /* NCO default after 201309: promote, where necessary, anything but doubles
+       Now default and activated redundantly --dbl switch */
     /* Conversion only for appropriate operation types */ 
     if(var->type != NC_DOUBLE && nco_op_typ != nco_op_min && nco_op_typ != nco_op_max) var=nco_var_cnf_typ((nc_type)NC_DOUBLE,var);
     
@@ -173,7 +175,7 @@ nco_cnv_mss_val_typ  /* [fnc] Convert missing_value, if any, to mss_val_out_typ
      ncra refreshes variable metadata (including missing_value, if any) 
      once per file (naturally), but refreshes variable values once per record.
      Current type of missing_value is not stored separately in variable structure
-     (maybe this is a mistake), so type of missing value may remain as promoted
+     (this is probably a mistake), so type of missing value may remain as promoted
      type for arithmetic.
      When next record is read and nco_typ_cnf_rth() promotion of new input 
      to arithmetic type (double, if necessary) will fail when it tries to
@@ -244,7 +246,7 @@ nco_var_cnf_typ /* [fnc] Return copy of input variable typecast to desired type
      This routine assumes missing_value, if any, to be same type as variable */
   if(var_in->type == var_out_typ) return var_in;
 
-  if(var_in->val.vp==NULL){
+  if(var_in->val.vp == NULL){
     /* Variable has no data when var_in.val.vp==NULL
        In this case function should only convert missing values 
        Accomplish this by temporarily masking off val_in by setting var_in->sz=0
@@ -513,7 +515,7 @@ nco_var_cnf_typ /* [fnc] Return copy of input variable typecast to desired type
   (void)cast_nctype_void(var_out_typ,&val_out);
 
   /* If var_in.vp empty then unmask sz */
-  if(val_in.vp==NULL) var_out->sz=sz_msk;
+  if(val_in.vp == NULL) var_out->sz=sz_msk;
 
   /* Free input variable data */
   val_in.vp=nco_free(val_in.vp);
@@ -553,7 +555,7 @@ nco_var_cnf_typ_tst /* [fnc] Return copy of input variable typecast to desired t
      This routine assumes missing_value, if any, to be same type as variable */
   if(var_in->type == var_out_typ) return var_in;
 
-  if(var_in->val.vp==NULL){
+  if(var_in->val.vp == NULL){
     /* Variable has no data when var_in.val.vp==NULL
        In this case function should only convert missing values 
        Accomplish this by temporarily masking off val_in by setting var_in->sz=0
@@ -822,7 +824,7 @@ nco_var_cnf_typ_tst /* [fnc] Return copy of input variable typecast to desired t
   (void)cast_nctype_void(var_out_typ,&val_out);
 
   /* If var_in.vp empty then unmask sz */
-  if(val_in.vp==NULL) var_out->sz=sz_msk;
+  if(val_in.vp == NULL) var_out->sz=sz_msk;
 
   /* Free input variable data */
   val_in.vp=nco_free(val_in.vp);
