@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.129 2014/09/25 04:41:15 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.151 2014/11/26 04:15:26 zender Exp $ */
 
 /* Purpose: NCO utilities for chunking */
 
@@ -66,6 +66,10 @@ nco_cnk_map_sng_get /* [fnc] Convert chunking map enum to string */
     return "xst";
   case nco_cnk_map_rew:
     return "rew";
+  case nco_cnk_map_nc4:
+    return "nc4";
+  case nco_cnk_map_nco:
+    return "nco";
   default: nco_dfl_case_cnk_map_err(); break;
   } /* end switch */
   /* Some compilers, e.g., SGI cc, need return statement to end non-void functions */
@@ -133,6 +137,7 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
  const int cnk_nbr, /* I [nbr] Number of chunksizes specified */
  const int cnk_map, /* I [enm] Chunking map */
  const int cnk_plc, /* I [enm] Chunking policy */
+ const size_t cnk_min_byt, /* I [B] Minimize size of variable to chunk */
  const size_t cnk_sz_byt, /* I [B] Chunk size in bytes */
  const size_t cnk_sz_scl, /* I [nbr] Chunk size scalar */
  cnk_sct * const cnk) /* O [sct] Chunking structure */
@@ -148,11 +153,12 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
   cnk->cnk_nbr=cnk_nbr;
   cnk->cnk_map=cnk_map;
   cnk->cnk_plc=cnk_plc;
+  cnk->cnk_min_byt=cnk_min_byt;
+  cnk->cnk_sz_byt=cnk_sz_byt;
   cnk->cnk_sz_scl=cnk_sz_scl;
-  cnk->cnk_sz_byt=cnk_sz_byt; /* For now, let cnk_sz_scl play double duty */
 
   /* Did user explicitly request chunking? */
-  if(cnk_nbr > 0 || cnk_sz_byt > 0UL || cnk_sz_scl > 0UL || cnk_map != nco_cnk_map_nil || cnk_plc != nco_cnk_plc_nil) cnk->flg_usr_rqs=True;
+  if(cnk_nbr > 0 || cnk_min_byt > 0UL || cnk_sz_byt > 0UL || cnk_sz_scl > 0UL || cnk_map != nco_cnk_map_nil || cnk_plc != nco_cnk_plc_nil) cnk->flg_usr_rqs=True;
 
   /* Chunks are atomic unit of HDF5 read/write
      Variables are compressed and check-summed one chunk at-a-time
@@ -179,6 +185,10 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
     cnk->cnk_sz_byt= (fl_sys_blk_sz > 0ULL) ? fl_sys_blk_sz : NCO_CNK_SZ_BYT_DFL;
   } /* end else */
     
+  /* Java chunking defaults:
+     http://www.unidata.ucar.edu/software/thredds/current/netcdf-java/reference/netcdf4Clibrary.html */
+  if(cnk_min_byt == 0ULL) cnk->cnk_min_byt= (fl_sys_blk_sz > 0ULL) ? 2*fl_sys_blk_sz : NCO_CNK_SZ_MIN_BYT_DFL;
+
   if(cnk_sz_byt <= 0ULL) cnk->cnk_sz_byt=NCO_CNK_SZ_BYT_DFL;
 
   /* Make uniform list of user-specified per-dimension chunksizes */
@@ -186,17 +196,22 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
 
   /* Set actual chunk policy and map to defaults as necessary
      20140821: Until today, defaults for map and policy were set independently
-     Now we consider four distinct cases: 
+     20141013: Tweak defaults so chunking always called (required to preserve input chunking)
+     Now we consider three distinct cases: 
      1. Neither map nor policy was explicitly set, and something else, e.g., size, was
      2. User set map not policy
      3. User set policy not map */
-  if(cnk->flg_usr_rqs && (cnk_map == nco_cnk_map_nil) && (cnk_plc == nco_cnk_plc_nil)){
-    cnk->cnk_map=nco_cnk_map_rd1;
-    cnk->cnk_plc=nco_cnk_plc_g2d;
+  if(cnk_map == nco_cnk_map_nil && cnk_plc == nco_cnk_plc_nil){
+    cnk->cnk_map=nco_cnk_map_xst;
+    cnk->cnk_plc=nco_cnk_plc_xst;
   } /* endif */
   if(cnk_map == nco_cnk_map_nil && cnk_plc != nco_cnk_plc_nil) cnk->cnk_map=nco_cnk_map_rd1;
   if(cnk_plc == nco_cnk_plc_nil && cnk_map != nco_cnk_map_nil) cnk->cnk_plc=nco_cnk_plc_g2d;
 
+  /* NCO-recommended chunking map is expected to change over time
+     cnk_map=nco assigns current NCO-recommended map */
+  if(cnk_map == nco_cnk_map_nco) cnk->cnk_map=nco_cnk_map_rd1;
+
   return rcd;
 } /* end nco_cnk_ini() */
 
@@ -333,6 +348,10 @@ nco_cnk_map_get /* [fnc] Convert user-specified chunking map to key */
   if(!strcmp(nco_cnk_map_sng,"cnk_map_xst")) return nco_cnk_map_xst;
   if(!strcmp(nco_cnk_map_sng,"rew")) return nco_cnk_map_rew;
   if(!strcmp(nco_cnk_map_sng,"cnk_map_rew")) return nco_cnk_map_rew;
+  if(!strcmp(nco_cnk_map_sng,"nc4")) return nco_cnk_map_nc4;
+  if(!strcmp(nco_cnk_map_sng,"cnk_map_nc4")) return nco_cnk_map_nc4;
+  if(!strcmp(nco_cnk_map_sng,"nco")) return nco_cnk_map_nco;
+  if(!strcmp(nco_cnk_map_sng,"cnk_map_nco")) return nco_cnk_map_nco;
 
   (void)fprintf(stderr,"%s: ERROR %s reports unknown user-specified chunking map %s\n",nco_prg_nm_get(),fnc_nm,nco_cnk_map_sng);
   nco_exit(EXIT_FAILURE);
@@ -798,7 +817,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   int cnk_plc; /* [enm] Chunking policy */
   int deflate; /* [enm] Deflate filter is on */
   int dmn_idx; /* [idx] Dimension index */
-  int dmn_nbr; /* [nbr] Number of dimensions for variable */
+  int dmn_nbr; /* [nbr] Number of dimensions for variable in output file */
   int fl_fmt; /* [enm] Input file format */
   int shuffle; /* [enm] Shuffle filter is on */
   int srg_typ; /* [enm] Storage type */
@@ -807,8 +826,6 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 
   nc_type var_typ_dsk; /* [nbr] Variable type */
 
-  nco_bool *flg_mch; /* [flg] Name match (absolute or relative) between chunking structure 'cnk_sct' and dimension 'dmn_cmn' */
-  nco_bool flg_ovr; /* [flg] Override default chunking with user-specified chunking for this dimension */
   nco_bool flg_usr_rqs; /* [flg] User requested checking */
   nco_bool is_rec_var; /* [flg] Record variable */
   nco_bool is_chk_var; /* [flg] Check-summed variable */
@@ -817,10 +834,12 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   nco_bool is_xpl_cnk; /* [flg] Explicitly chunked variable */
   nco_bool must_be_chunked; /* [flg] Variable must be chunked */
 
-  size_t *cnk_sz=NULL; /* [nbr] Chunksize list */
+  size_t *cnk_sz=NULL; /* [nbr] Chunksize list in output file */
+  size_t cnk_min_byt; /* [B] Minimize size of variable to chunk */
   size_t cnk_sz_dfl; /* [nbr] Chunksize default */
   size_t cnk_sz_scl; /* [nbr] Chunk size scalar */
   size_t typ_sz; /* [B] Bytes per value */
+  size_t var_sz_byt; /* [B] Size of variable in output file */
 
   static short FIRST_CALL=True;
 
@@ -831,8 +850,9 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   cnk_nbr=cnk->cnk_nbr;
   cnk_map=cnk->cnk_map;
   cnk_plc=cnk->cnk_plc;
-  cnk_sz_scl=cnk->cnk_sz_scl;
+  cnk_min_byt=cnk->cnk_min_byt;
   cnk_sz_byt=cnk->cnk_sz_byt;
+  cnk_sz_scl=cnk->cnk_sz_scl;
   cnk_dmn=cnk->cnk_dmn;
 
   /* Only use NCO chunking when user explicitly sets a chunking option */
@@ -861,11 +881,10 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     (void)fprintf(stdout,"%s: INFO User requested chunking or unchunking\n",nco_prg_nm_get());
     if(nco_dbg_lvl_get() >= nco_dbg_scl  && nco_dbg_lvl_get() != nco_dbg_dev){
       (void)fprintf(stdout,"cnk_plc, cnk_map: %s, %s\n",nco_cnk_plc_sng_get(cnk_plc),nco_cnk_map_sng_get(cnk_map));
-      (void)fprintf(stdout,"cnk_sz_scl, cnk_sz_byt: %lu, %lu\n",(unsigned long)cnk_sz_scl,(unsigned long)cnk_sz_byt);
+      (void)fprintf(stdout,"cnk_sz_scl, cnk_sz_byt, cnk_min_byt: %lu, %lu, %lu\n",(unsigned long)cnk_sz_scl,(unsigned long)cnk_sz_byt,(unsigned long)cnk_min_byt);
       if(cnk_nbr > 0){
-        (void)fprintf(stdout,"idx dmn_nm\tcnk_sz:\n");
-        for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++)
-	  (void)fprintf(stdout,"%2d %s\t%lu\n",cnk_idx,cnk_dmn[cnk_idx]->nm,(unsigned long)cnk_dmn[cnk_idx]->sz);
+        (void)fprintf(stdout,"idx cnk_nm\tcnk_sz:\n");
+        for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++) (void)fprintf(stdout,"%2d %s\t%lu\n",cnk_idx,cnk_dmn[cnk_idx]->nm ? cnk_dmn[cnk_idx]->nm : cnk_dmn[cnk_idx]->nm_fll,(unsigned long)cnk_dmn[cnk_idx]->sz);
       } /* cnk_nbr == 0 */
     } /* endif dbg */
   } /* endif dbg */
@@ -896,6 +915,11 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++)
     if(dmn_cmn[dmn_idx].is_rec_dmn) is_rec_var=True;
 
+  /* How big is variable? */
+  var_sz_byt=typ_sz;
+  for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++)
+    var_sz_byt*= dmn_cmn[dmn_idx].NON_HYP_DMN ? dmn_cmn[dmn_idx].sz : dmn_cmn[dmn_idx].dmn_cnt;
+
   /* Is variable compressed? */
   (void)nco_inq_var_deflate(grp_id_out,var_id_out,&shuffle,&deflate,(int *)NULL);
   if(deflate) is_cmp_var=True; 
@@ -908,37 +932,42 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   if(is_rec_var || is_chk_var || is_cmp_var) must_be_chunked=True; else must_be_chunked=False;
 
   /* Is variable currently chunked? */
-  if(nco_fmt_xtn_get() != nco_fmt_xtn_hdf4 || NCO_NC_LIB_VERSION >= 433) is_chunked=nco_cnk_dsk_inq(grp_id_in,var_id_in);
+  if(nco_fmt_xtn_get() != nco_fmt_xtn_hdf4 || NC_LIB_VERSION >= 433) is_chunked=nco_cnk_dsk_inq(grp_id_in,var_id_in);
 
-  /* Does this variable have any user-chunked dimensions? */
-  if(cnk_plc == nco_cnk_plc_xpl){
-    for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++)
-      for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
-        if(cnk_dmn[cnk_idx]->nm_fll){
-          if(!strcmp(cnk_dmn[cnk_idx]->nm_fll,dmn_cmn[dmn_idx].nm_fll)) break;
-        }else{
-          if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm)) break;
-        } /* end else */
-      } /* end loop over cnk_idx */
-    if(dmn_idx != dmn_nbr) is_xpl_cnk=True;
-  } /* end plc_xpl */
+  /* Does variable have any user-chunked dimensions? */
+  for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
+    for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
+      if(cnk_dmn[cnk_idx]->nm_fll){
+	if(!strcmp(cnk_dmn[cnk_idx]->nm_fll,dmn_cmn[dmn_idx].nm_fll)) break;
+      }else{
+	if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm)) break;
+      } /* end else */
+    } /* end loop over cnk_idx */
+    if(cnk_idx != cnk_nbr) break;
+  } /* end loop over dmn_idx */
+  if(dmn_idx != dmn_nbr) is_xpl_cnk=True;
+
+  /* Let netCDF layer determine chunking */
+  if(cnk_map == nco_cnk_map_nc4) return;
 
   if(must_be_chunked){
     /* Some variables simply must be chunked */
     if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s %s must be chunked (record, compressed, or check-summed variable)\n",nco_prg_nm_get(),fnc_nm,var_nm);
   }else{
-    /* Explicitly exit this chunking function now (and thus implement netCDF4-default chunking behavior) for variables that are... */
-    if((cnk_plc == nco_cnk_plc_xpl && !is_xpl_cnk) || /* ...not explicitly chunked... */
+    /* Exit chunking function now (and thus implement netCDF4-default chunking behavior) for variables that are... */
+    if((var_sz_byt < cnk_min_byt) || /* ...too small in size... */
+       (cnk_plc == nco_cnk_plc_xpl && !is_xpl_cnk) || /* ...not explicitly chunked... */
        (cnk_plc == nco_cnk_plc_xst && !is_chunked) || /* ...not already chunked... */
-       (cnk_plc == nco_cnk_plc_g2d && dmn_nbr < 2) || /* ...much too small... */
-       (cnk_plc == nco_cnk_plc_g3d && dmn_nbr < 3) || /* ...too small... */
+       (cnk_plc == nco_cnk_plc_g2d && dmn_nbr < 2) || /* ...much too small in rank... */
+       (cnk_plc == nco_cnk_plc_g3d && dmn_nbr < 3) || /* ...too small in rank... */
        (cnk_plc == nco_cnk_plc_uck) || /* ...intentionally unchunked... */
        False){
-      /* If variable is chunked */
+      /* If variable is chunked in input */
       if(is_chunked){
 	/* Turn-off chunking for this variable */
 	if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s unchunking %s\n",nco_prg_nm_get(),fnc_nm,var_nm);
 	if(shuffle) (void)fprintf(stdout,"%s: WARNING %s reports variable %s has shuffle flag set before unchunking. Expect the worst.",nco_prg_nm_get(),fnc_nm,var_nm);
+	/* Redundant since default netCDF srg_typ = NC_CONTIGUOUS for variables that need not be chunked */
 	(void)nco_def_var_chunking(grp_id_out,var_id_out,srg_typ,cnk_sz);
       }else{ /* !chunked */
 	if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s not unchunking %s because it is not chunked\n",nco_prg_nm_get(),fnc_nm,var_nm);
@@ -949,7 +978,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     } /* !turn-off chunking */
   } /* !must_be_chunked */
 
-  /* Since routine has not returned yet, this variable will definitely be chunked */
+  /* Routine has not returned yet so this variable will definitely be chunked */
   srg_typ=NC_CHUNKED; /* [enm] Storage type */
   if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s %schunking %s\n",nco_prg_nm_get(),fnc_nm,(is_chunked ? "re-" : "" ),var_nm);
 
@@ -958,8 +987,56 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 
   if(cnk_map == nco_cnk_map_xst){
     /* Set chunksizes to existing sizes for this variable */
+
     if(is_chunked){
-      (void)nco_inq_var_chunking(grp_id_in,var_id_in,(int *)NULL,cnk_sz);
+      char **dmn_nm_in; /* [sng] Dimension names for this variable in input file */
+      int *dmn_id_in; /* [id] Dimension IDs for this variable in input file */
+      int dmn_idx_in; /* [idx] Counter for input dimensions */
+      int dmn_nbr_in; /* [nbr] Number of dimensions for variable in input file */
+      size_t *cnk_in=NULL; /* [nbr] Chunksize list in input file */
+
+      (void)nco_inq_varndims(grp_id_in,var_id_in,&dmn_nbr_in);
+      cnk_in=(size_t *)nco_malloc(dmn_nbr_in*sizeof(size_t));    
+      dmn_id_in=(int *)nco_malloc(dmn_nbr_in*sizeof(int));    
+      dmn_nm_in=(char **)nco_malloc(dmn_nbr_in*sizeof(char *));    
+      for(dmn_idx=0;dmn_idx<dmn_nbr_in;dmn_idx++) 
+	dmn_nm_in[dmn_idx]=(char *)nco_calloc(NC_MAX_NAME+1L,sizeof(char));
+
+      (void)nco_inq_var_chunking(grp_id_in,var_id_in,(int *)NULL,cnk_in);
+      (void)nco_inq_vardimid(grp_id_in,var_id_in,dmn_id_in);
+      for(dmn_idx=0;dmn_idx<dmn_nbr_in;dmn_idx++) 
+	(void)nco_inq_dimname(grp_id_in,dmn_id_in[dmn_idx],dmn_nm_in[dmn_idx]);
+
+      /* 20141124: 
+	 In most cases cnk_in may be safely assigned to cnk_sz
+	 However, operators like ncecat and ncwa change variable dimensionality, and ncpdq changes order
+	 With these operators, re-arrange input chunksizes for output */
+      for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
+	for(dmn_idx_in=0;dmn_idx_in<dmn_nbr_in;dmn_idx_in++){
+	  if(!strcmp(dmn_cmn[dmn_idx].nm,dmn_nm_in[dmn_idx_in])){
+	      cnk_sz[dmn_idx]=cnk_in[dmn_idx_in];
+	      break;
+	  } /* endif */
+	} /* end loop over dmn_idx_in */
+	if(dmn_idx_in == dmn_nbr_in){
+	  /* Output file dimension not found in input file */
+	  assert(nco_prg_id_get() == ncecat);
+	  if(dmn_cmn[dmn_idx].NON_HYP_DMN){
+	    if(dmn_cmn[dmn_idx].sz == 0) cnk_sz[dmn_idx]=1UL; else cnk_sz[dmn_idx]=dmn_cmn[dmn_idx].sz;
+	  }else{ /* !NON_HYP_DMN */
+	    cnk_sz[dmn_idx]=dmn_cmn[dmn_idx].dmn_cnt;
+	  } /* !NON_HYP_DMN */
+	  if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: INFO %s reports variable %s output dimension %s not found in input file. Setting default chunksize for this dimension to = %lu\n",nco_prg_nm_get(),fnc_nm,var_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_sz[dmn_idx]);
+	} /* endif dimension not in input file */
+      } /* end loop over dmn_idx */
+
+      /* Memory management */
+      if(cnk_in) cnk_in=(size_t *)nco_free(cnk_in);
+      if(dmn_id_in) dmn_id_in=(int *)nco_free(dmn_id_in);
+      for(dmn_idx=0;dmn_idx<dmn_nbr_in;dmn_idx++) 
+	if(dmn_nm_in[dmn_idx]) dmn_nm_in[dmn_idx]=(char *)nco_free(dmn_nm_in[dmn_idx]);
+      if(dmn_nm_in) dmn_nm_in=(char **)nco_free(dmn_nm_in);
+
       /* Allow existing chunksizes to be over-ridden by explicitly specified chunksizes */
       goto cnk_xpl_override;
     } /* !is_chunked */
@@ -991,9 +1068,10 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
       /* Record dimension size in output file is zero until first write
 	 Obtain record dimension size from lmt_all structure (for nco_cnk_sz_set()) */
       if(dmn_cmn[dmn_idx].NON_HYP_DMN){
-        /* When not hyperslabbed, use input record dimension size ... */
-        cnk_sz[dmn_idx]=dmn_cmn[dmn_idx].sz;
-	/* 20140518: As of netCDF 4.3.2, employ smarter defaults for record dimension */
+        /* When not hyperslabbed, use input record dimension size, except workaround zero size
+	   reported for new record dimensions before anything is written */
+	if(dmn_cmn[dmn_idx].sz == 0) cnk_sz[dmn_idx]=1UL; else cnk_sz[dmn_idx]=dmn_cmn[dmn_idx].sz;
+	/* 20140518: As of netCDF 4.3.2, employ smarter defaults for record dimension in 1-D variables */
 	if(dmn_nbr == 1) cnk_sz[dmn_idx]=NCO_CNK_SZ_BYT_R1D_DFL/typ_sz;
       }else{ /* !NON_HYP_DMN */
         /* ... and when hyperslabbed, use user-specified count */
@@ -1041,24 +1119,39 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   } /* !nco_cnk_map_lfp */
 
   if(cnk_map == nco_cnk_map_rew){
-    /* Described by Russ Rew at http://www.unidata.ucar.edu/staff/russ/public/chunk_shape_3D.py
-       ncks -O -C -4 -D 6 -v four_dmn_rec_var --cnk_map=rew -p ~/nco/data in.nc ~/foo.nc */
+
+    /* Apply only to 3-D variables */
+    if(dmn_nbr != 3) goto cnk_xpl_override;
+
+    /* Implementation by Russ Rew at http://www.unidata.ucar.edu/staff/russ/public/chunk_shape_3D.py
+       >>> import cnk
+       >>> cnk.chunk_shape_3D(varShape=(98128,277,349),valSize=4,chunkSize=4096)
+       [33, 5, 6]
+       Test case is (time,lat,lon) = 98128 x 277 x 349
+       ncks -O -C -4 -D 5 -v three_dmn_rec_var --cnk_byt=128 --cnk_map=rew -p ~/nco/data in.nc ~/foo.nc
+       ncks -O -C -4 -D 5 -v var --cnk_byt=4096 --cnk_map=rew -p ~/nco/data cnk.nc ${DATA}/nco_bm/cnk_rew.nc */
     double cnk_val_nbr;
     double dmn_sz_prd=1.0; /* [nbr] Number of elements in output variable */
     double cnk_nbr_xct; /* [nbr] Exact number of ideal chunks needed to store variable */
     double cnk_nbr_2D_axs; /* [nbr] Exact number of ideal chunks along each 2D axis */
     double fct_ncr=1.0; /* [frc] Factor by which to increase chunk size */
+    size_t *cnk_sz_prt; /* [nbr] Perturbed chunk size (base chunk size plus zero or one) */
+    size_t *cnk_sz_rgn; /* [nbr] Original (first-guess) chunk size (no adjustments) */
+    size_t *prt_cff; /* [nbr] Rerturbation to base chunk size for each dimension, also [0,1] multiplier for each power of two in this permutation index */
+    size_t *two_pwr_idx; /* [nbr] Two-to-the-power-of-the-array-index */
     size_t *var_shp; /* [nbr] Shape of variable */
 
     /* Allocate space to hold variable shape */
+    cnk_sz_rgn=(size_t *)nco_malloc(dmn_nbr*sizeof(size_t));    
+    cnk_sz_prt=(size_t *)nco_malloc(dmn_nbr*sizeof(size_t));    
+    prt_cff=(size_t *)nco_malloc(dmn_nbr*sizeof(size_t));    
+    two_pwr_idx=(size_t *)nco_malloc(dmn_nbr*sizeof(size_t));    
     var_shp=(size_t *)nco_malloc(dmn_nbr*sizeof(size_t));    
 
     cnk_val_nbr=cnk_sz_byt/(double)typ_sz;
     for(dmn_idx=0;dmn_idx<=dmn_nbr-1;dmn_idx++){
       /* Store shape for future use */
-      /* 20140131: fxm this gets wrong value for input record dimension size unless hyperslabbed. Why? */
-      if(dmn_cmn[dmn_idx].is_rec_dmn) var_shp[dmn_idx]= (dmn_cmn[dmn_idx].NON_HYP_DMN) ? dmn_cmn[dmn_idx].dmn_cnt : dmn_cmn[dmn_idx].sz; else var_shp[dmn_idx]= (dmn_cmn[dmn_idx].NON_HYP_DMN) ? dmn_cmn[dmn_idx].sz : dmn_cmn[dmn_idx].dmn_cnt;
-      assert(var_shp[dmn_idx] > 0L);
+      var_shp[dmn_idx]= (dmn_cmn[dmn_idx].NON_HYP_DMN) ? dmn_cmn[dmn_idx].sz : dmn_cmn[dmn_idx].dmn_cnt;
       /* Determine hyperslab size */
       dmn_sz_prd*=var_shp[dmn_idx];
     } /* end loop over dmn_idx */
@@ -1067,26 +1160,84 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     cnk_nbr_2D_axs=pow(cnk_nbr_xct,0.25);
 
     if(var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs) < 1.0){
-      cnk_sz[0]=1L;
-      cnk_nbr_2D_axs=1.0/sqrt((double)var_shp[0]);
+      cnk_sz_rgn[0]=1L;
+      cnk_nbr_2D_axs/=sqrt((double)var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs));
     }else{
-      cnk_sz[0]=var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs);
+      cnk_sz_rgn[0]=var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs); // Rew13 uses // for integer arithmetic here
     } /* endif */
 
     for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at 1 */
       if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) fct_ncr*=cnk_nbr_2D_axs/var_shp[dmn_idx];
     for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at 1 */
-      if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) cnk_sz[dmn_idx]=1L; else cnk_sz[dmn_idx]=fct_ncr*var_shp[dmn_idx]/cnk_nbr_2D_axs;
+      if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) cnk_sz_rgn[dmn_idx]=1L; else cnk_sz_rgn[dmn_idx]=fct_ncr*var_shp[dmn_idx]/cnk_nbr_2D_axs;
+
+    /* First-guess estimate of chunk size */
+    size_t cnk_sz_prd=1L;
+    for(dmn_idx=0;dmn_idx<=dmn_nbr-1;dmn_idx++) cnk_sz_prd*=cnk_sz_rgn[dmn_idx];
+    assert(cnk_sz_prd*typ_sz <= cnk_sz_byt);
+
+    /* prm_idx = prm_cff[0]*2^0 + prm_cff[1]*2^1 + prm_cff[2]*2^2 + ... + prm_cff[dmn_nbr-1]*2^(dmn_nbr-1) */
+    two_pwr_idx[0]=1L;
+    for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) two_pwr_idx[dmn_idx]=2L*two_pwr_idx[dmn_idx-1];
+    size_t two_pwr_rnk=2L*two_pwr_idx[dmn_nbr-1];
+
+    int sum_idx; /* [idx] Counting index for partial sums [dmn_idx+1..dmn_nbr-1] */
+    long cnk_gap; /* [B] Difference between actual and requested chunksize */
+    long cnk_gap_prt; /* [B] Difference between perturbed and requested chunksize */
+    size_t prm_idx; /* [idx] Permutation index [0..2^(dmn_nbr-1)] */
+    size_t prt_sum; /* [nbr] Partial sum (sum of coefficients times powers of two for higher powers */
+    /* Score initial guess */
+    cnk_gap=cnk_sz_byt-cnk_sz_prd*typ_sz;
+    /* In case initial guess is lucky and permutation loop breaks before completing */
+    for(dmn_idx=0;dmn_idx<=dmn_nbr-1;dmn_idx++) cnk_sz[dmn_idx]=cnk_sz_rgn[dmn_idx];
+
+    /* Loop through permutations of adjusting first-estimate chunk size by plus one
+       NB: Skip permutation prm_idx=0 since it is degenerate and does not change first-guess chunk sizes */
+    for(prm_idx=1;prm_idx<two_pwr_rnk;prm_idx++){ /* NB: Loop starts at 1 to skip degenerate perumutation */
+      if(cnk_gap == 0L) break;
+      cnk_sz_prd=1L;
+      /* Fill-in coefficient from MSB to LSB */
+      for(dmn_idx=dmn_nbr-1;dmn_idx>=0;dmn_idx--){ /* NB: descending loop */
+	cnk_sz_prt[dmn_idx]=cnk_sz_rgn[dmn_idx];
+	prt_sum=prt_cff[dmn_idx]=0UL;
+	/* Partial sum of higher powers */
+	for(sum_idx=dmn_idx+1;sum_idx<=dmn_nbr-1;sum_idx++) prt_sum+=prt_cff[sum_idx]*two_pwr_idx[sum_idx];
+	prt_cff[dmn_idx]=(prm_idx-prt_sum)/two_pwr_idx[dmn_idx];
+	cnk_sz_prt[dmn_idx]+=prt_cff[dmn_idx];
+	cnk_sz_prd*=cnk_sz_prt[dmn_idx];
+      } /* dmn_idx */
+      /* Test gap narrowness */
+      cnk_gap_prt=cnk_sz_byt-cnk_sz_prd*typ_sz;
+
+      if(nco_dbg_lvl_get() >= nco_dbg_var){
+	(void)fprintf(stdout,"prm_idx = %lu, cnk_gap = %ld, cnk_sz_prd = %lu, cnk_gap_prt = %ld, prt_sum = %lu\n",(unsigned long)prm_idx,cnk_gap,(unsigned long)cnk_sz_prd,cnk_gap_prt,(unsigned long)prt_sum);
+	(void)fprintf(stdout,"idx dmn_nm\tdmn_sz\tvar_shp\tsz_rgn\tsz_prt\tprt_cff\ttwo_pwr:\n");
+	for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++) (void)fprintf(stdout,"%2d %s\t\t%lu\t%lu\t%lu\t%lu\t%lu\t%lu\n",dmn_idx,dmn_cmn[dmn_idx].nm,(unsigned long)dmn_cmn[dmn_idx].sz,(unsigned long)var_shp[dmn_idx],(unsigned long)cnk_sz_rgn[dmn_idx],(unsigned long)cnk_sz_prt[dmn_idx],(unsigned long)prt_cff[dmn_idx],(unsigned long)two_pwr_idx[dmn_idx]);
+      } /* endif dbg */
+
+      if(cnk_gap_prt >= 0L && cnk_gap_prt < cnk_gap){
+	/* Candidate improves best previous guess */
+	for(dmn_idx=0;dmn_idx<=dmn_nbr-1;dmn_idx++){
+	  cnk_sz[dmn_idx]=cnk_sz_prt[dmn_idx];
+	  cnk_gap=cnk_gap_prt;
+	} /* end loop over dimensions */
+      } /* endif gap */
+    } /* end loop over permutations */
 
     if(nco_dbg_lvl_get() >= nco_dbg_var){
       (void)fprintf(stdout,"map rew debugging:\n");
-      (void)fprintf(stdout,"cnk_nbr_xct = %g, cnk_val_nbr = %g, dmn_sz_prd = %g\n",cnk_nbr_xct,cnk_val_nbr,dmn_sz_prd);
+      (void)fprintf(stdout,"cnk_nbr_xct = %g, cnk_val_nbr = %g, dmn_sz_prd = %g, cnk_sz_prd = %lu\n",cnk_nbr_xct,cnk_val_nbr,dmn_sz_prd,(unsigned long)cnk_sz_prd);
       (void)fprintf(stdout,"idx dmn_nm\tdmn_sz\tvar_shp\tcnk_sz:\n");
       for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++) (void)fprintf(stdout,"%2d %s\t\t%lu\t%lu\t%lu\n",dmn_idx,dmn_cmn[dmn_idx].nm,(unsigned long)dmn_cmn[dmn_idx].sz,(unsigned long)var_shp[dmn_idx],(unsigned long)cnk_sz[dmn_idx]);
     } /* endif dbg */
 
     /* Free shape space */
-    if(var_shp) var_shp=(size_t *)nco_free(var_shp);    
+    if(cnk_sz_prt) cnk_sz_prt=(size_t *)nco_free(cnk_sz_prt);
+    if(cnk_sz_rgn) cnk_sz_rgn=(size_t *)nco_free(cnk_sz_rgn);
+    if(prt_cff) prt_cff=(size_t *)nco_free(prt_cff);
+    if(two_pwr_idx) two_pwr_idx=(size_t *)nco_free(two_pwr_idx); 
+    if(var_shp) var_shp=(size_t *)nco_free(var_shp); 
+
   } /* !nco_cnk_map_rew */
 
   /* Override "reasonable" defaults with explicitly set uniform scalar chunksize, if any */
@@ -1112,78 +1263,73 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 cnk_xpl_override: /* end goto */
 
   /* Override "reasonable" defaults with explicitly set per-dimension sizes, if any */
-  flg_mch=(nco_bool *)nco_malloc(dmn_nbr*sizeof(nco_bool));
-  /* Loop over all dimensions in this variable */
   for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
 
-    /* Initialize to false then override */
-    flg_mch[dmn_idx]=False;
+    /* Full-names have priority in matching...first full-name match wins */
+    for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++)
+      if(cnk_dmn[cnk_idx]->nm_fll)
+        if(!strcmp(cnk_dmn[cnk_idx]->nm_fll,dmn_cmn[dmn_idx].nm_fll))
+	  break;
 
-    /* Loop over all user-specified chunk-sizes */
-    for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
+    /* If no full-names match, then first short-name (relative name) match wins */
+    if(cnk_idx == cnk_nbr)
+      for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++)
+	if(!cnk_dmn[cnk_idx]->nm_fll)
+	  if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm))
+	    break;
+      
+    /* If no match then no override so continue to next dimension */
+    if(cnk_idx == cnk_nbr) continue;
 
-      if(cnk_dmn[cnk_idx]->nm_fll){
-        if(!strcmp(cnk_dmn[cnk_idx]->nm_fll,dmn_cmn[dmn_idx].nm_fll)) flg_mch[dmn_idx]=True;
-      }else{
-        if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm)) flg_mch[dmn_idx]=True;
-      } /* end else */
+    /* Override default chunking with user-specified chunking for this dimension if... */
+    if(
+       /* ... Policy is anything but r1d or ...*/
+       (cnk_plc != nco_cnk_plc_r1d) ||
+       /* ... Policy is r1d and this is the matching r1d coordinate or ... */
+       (cnk_plc == nco_cnk_plc_r1d && (dmn_nbr == 1 && is_rec_var)) ||
+       False){
+      /* Perform override */
+      cnk_sz[dmn_idx]=cnk_dmn[cnk_idx]->sz;
+    }else{
+      /* Override was not performed due to policy, so continue to next dimension */
+      continue;
+    } /* endif */
 
-      /* User-specified name matches current dimension name */
-      if(flg_mch[dmn_idx]){
-	flg_ovr=False;
+    /* Sanity checks for dimensions that were over-ridden by user-specified chunksizes */
 
-	/* Override default chunking with user-specified chunking for this dimension if... */
-	if(
-	   /* ... Policy is anything but r1d or ...*/
-	   (cnk_plc != nco_cnk_plc_r1d) ||
-	   /* ... Policy is r1d and this is the matching r1d coordinate or ... */
-	   (cnk_plc == nco_cnk_plc_r1d && (dmn_nbr == 1 && is_rec_var)) ||
-	   False){
-	  /* Perform override */
-	  cnk_sz[dmn_idx]=cnk_dmn[cnk_idx]->sz;
-	  flg_ovr=True;
-	} /* endif */
+    /* Is this a record dimension? */
+    if(dmn_cmn[dmn_idx].is_rec_dmn){
+      /* dmn_sz of record dimension can/will be zero in output file
+	 Allow (though warn) when cnk_sz > dmn_sz in such cases */
+      if(dmn_cmn[dmn_idx].NON_HYP_DMN){
+	if(dmn_cmn[dmn_idx].sz > 0 && /* Warn only after records have been written */
+	   cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
+	  (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize %lu which exceeds current output file record dimension size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
+	} /* endif too big */
+      }else{ /* !NON_HYP_DMN */
+	if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].dmn_cnt){
+	  (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize = %lu which exceeds user-specified record dimension input hyperslab size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].dmn_cnt);
+	} /* endif too big */
+      } /* !NON_HYP_DMN */
+    }else{ /* !rcd_dmn_id */
+      if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
+	/* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
+	(void)fprintf(stderr,"%s: WARNING %s trimming user-specified fixed dimension %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
+	/* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
+	cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
+      } /* endif */
+    } /* !rcd_dmn_id */
 
-	/* Sanity checks for dimensions that were over-ridden by user-specified chunksizes */
-	if(flg_ovr){
-	  /* Is this a record dimension? */
-	  if(dmn_cmn[dmn_idx].is_rec_dmn){
-	    /* dmn_sz of record dimension can/will be zero in output file
-	       Allow (though warn) when cnk_sz > dmn_sz in such cases */
-	    if(dmn_cmn[dmn_idx].NON_HYP_DMN){
-	      if(dmn_cmn[dmn_idx].sz > 0 && /* Warn only after records have been written */
-		 cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
-		(void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize %lu which exceeds current output file record dimension size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
-	      } /* endif too big */
-	    }else{ /* !NON_HYP_DMN */
-	      if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].dmn_cnt){
-		(void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize = %lu which exceeds user-specified record dimension input hyperslab size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].dmn_cnt);
-	      } /* endif too big */
-	    } /* !NON_HYP_DMN */
-	  }else{ /* !rcd_dmn_id */
-	    if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
-	      /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
-	      (void)fprintf(stderr,"%s: WARNING %s trimming user-specified fixed dimension %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
-	      /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
-	      cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
-	    } /* endif */
-	  } /* !rcd_dmn_id */
-	} /* !flg_ovr */
-	/* Dimension matched this chunk name, no need to search other chunk names */
-	break;
-      } /* cnk_nm != dmn_nm */
-    } /* end loop over dimensions */
-  } /* end loop over cnk */
-  if(flg_mch) flg_mch=(nco_bool *)nco_free(flg_mch);
+  } /* end loop over dmn_idx */
 
-  /* Status: Previous block implemented per-dimension checks on user-requested chunksizes only
-     Block below implements similar final safety check for ALL dimensions and ALL chunking maps
+  /* Status: Previous loop implemented per-dimension checks on user-requested chunksizes only
+     Loop below implements similar final safety check for ALL dimensions and ALL chunking maps
      Check trims fixed (not record) dimension chunksize to never be larger than dimension size */
   for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
     if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
       if(!dmn_cmn[dmn_idx].is_rec_dmn){
         /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
-        (void)fprintf(stderr,"%s: WARNING %s final check trimming %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_sz[dmn_idx],(unsigned long)dmn_cmn[dmn_idx].sz);
+        if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stderr,"%s: INFO %s final check trimming chunksize of \"%s\" dimension from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_sz[dmn_idx],(unsigned long)dmn_cmn[dmn_idx].sz);
         /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
         cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
       } /* rcd_dmn_id */
