@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.h,v 1.39 2014/08/14 22:44:39 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.h,v 1.42 2014/10/17 15:42:40 zender Exp $ */
 
 /* Purpose: Description (definition) of chunking functions */
 
@@ -50,7 +50,9 @@ enum nco_cnk_map{ /* [enm] Chunking conversion map */
   nco_cnk_map_prd, /* 4 [enm] Chunksize product is scalar size specified */
   nco_cnk_map_lfp, /* 5 [enm] Chunksizes of lefter dimensions flexes to matches scalar size specified */
   nco_cnk_map_xst, /* 6 [enm] Chunksize equals chunk-sizes in input file */
-  nco_cnk_map_rew /* 7 [enm] Chunksize balances access to 1D and 2D slabs of 3D variable */
+  nco_cnk_map_rew, /* 7 [enm] Chunksize balances access to 1D and 2D slabs of 3D variable */
+  nco_cnk_map_nc4, /* 8 [enm] Chunksize determined by netCDF layer */
+  nco_cnk_map_nco /* 9 [enm] Chunksize determined by current "best" NCO algorithm */
 }; /* end nco_cnk_map enum */
 
 #ifdef __cplusplus
@@ -78,6 +80,7 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
  const int cnk_nbr, /* I [nbr] Number of chunksizes specified */
  const int cnk_map, /* I [enm] Chunking map */
  const int cnk_plc, /* I [enm] Chunking policy */
+ const size_t cnk_min_byt, /* I [B] Minimize size of variable to chunk */
  const size_t cnk_sz_byt, /* I [B] Chunk size in bytes */
  const size_t cnk_sz_scl, /* I [nbr] Chunk size scalar */
  cnk_sct * const cnk); /* O [sct] Chunking structure */
