@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_scm.c,v 1.57 2014/08/21 18:22:44 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_scm.c,v 1.59 2014/10/09 15:00:35 zender Exp $ */
 
 /* Purpose: Software configuration management */
 
@@ -31,7 +31,7 @@ cvs_vrs_prs(void) /* [fnc] Return CVS version string */
   /* Unexpanded cvs keywords in cvs_Name trigger GCC 4.0+ warning
      "./src/nco/nco_scm.c:81: warning: offset outside bounds of constant string"
      because routine looks for cvs_Name+7 later on */
-  char cvs_Name[]="$Name: nco-4_4_6 $";
+  char cvs_Name[]="$Name: nco-4_4_7 $";
   const char dlr_nm_cln_spc[]="$Name: "; /* [sng] Dollar name colon space */
   const char nco_sng[]="nco"; 
   const char spc_dlr[]=" $"; /* [sng] Space dollar */
@@ -166,6 +166,7 @@ nco_vrs_prn /* [fnc] Print NCO version */
   int vrs_cvs_lng;
   
   const char date_cpp[]=__DATE__; /* [sng] Date from C pre-processor */
+  const char time_cpp[]=__TIME__; /* [sng] Time from C pre-processor */
   /*  const char time_cpp[]=__TIME__; *//* [sng] Time from C pre-processor */
   const char vrs_cpp[]=TKN2SNG(VERSION); /* [sng] Version from C pre-processor */
   const char hst_cpp[]=TKN2SNG(HOSTNAME); /* [sng] Hostname from C pre-processor */
@@ -184,9 +185,9 @@ nco_vrs_prn /* [fnc] Print NCO version */
 
   if(strlen(CVS_Revision) > strlen("*Revision*") || strlen(CVS_Revision) < strlen("*Revision*")){
     /* CVS_Revision is defined */
-    vrs_cvs_lng=strrchr(CVS_Revision,'$')-strchr(CVS_Revision,':')-3;
-    vrs_rcs=(char *)nco_malloc((vrs_cvs_lng+1)*sizeof(char));
-    (void)strncpy(vrs_rcs,strchr(CVS_Revision,':')+2,(size_t)vrs_cvs_lng);
+    vrs_cvs_lng=strrchr(CVS_Revision,'$')-strchr(CVS_Revision,':')-3L;
+    vrs_rcs=(char *)nco_malloc((vrs_cvs_lng+1L)*sizeof(char));
+    (void)strncpy(vrs_rcs,strchr(CVS_Revision,':')+2L,(size_t)vrs_cvs_lng);
     vrs_rcs[vrs_cvs_lng]='\0';
   }else{
     /* CVS_Revision is undefined */
@@ -198,7 +199,9 @@ nco_vrs_prn /* [fnc] Print NCO version */
   if(strlen(CVS_Id) > strlen("*Id*")){
     (void)fprintf(stderr,"NCO netCDF Operators version %s last modified %s built %s on %s by %s\n",vrs_cpp,date_cvs,date_cpp,hst_cpp,usr_cpp);
   }else{
-    (void)fprintf(stderr,"NCO netCDF Operators version %s built %s on %s by %s\n",vrs_cpp,date_cpp,hst_cpp,usr_cpp);
+    /* 20141008: Try new nco.h-based versioning */
+    /*    (void)fprintf(stderr,"NCO netCDF Operators version %s built %s on %s by %s\n",vrs_cpp,date_cpp,hst_cpp,usr_cpp);*/
+    (void)fprintf(stderr,"NCO netCDF Operators version %s built by %s on %s at %s %s\n",NCO_VERSION,usr_cpp,hst_cpp,date_cpp,time_cpp);
   } /* endif */
   if(strlen(CVS_Id) > strlen("*Id*")){
     (void)fprintf(stderr,"%s version %s\n",nco_prg_nm_get(),vrs_cvs);
