@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncrename.c,v 1.205 2014/09/26 23:03:48 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncrename.c,v 1.208 2014/10/10 15:15:35 zender Exp $ */
 
 /* ncrename -- netCDF renaming operator */
 
@@ -115,8 +115,8 @@ main(int argc,char **argv)
 
   char *obj_nm=NULL;
 
-  const char * const CVS_Id="$Id: ncrename.c,v 1.205 2014/09/26 23:03:48 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.205 $";
+  const char * const CVS_Id="$Id: ncrename.c,v 1.208 2014/10/10 15:15:35 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.208 $";
   const char * const opt_sht_lst="a:D:d:g:hl:Oo:p:rv:-:";
   const char dlm_chr='@'; /* Character delimiting variable from attribute name  */
   const char opt_chr='.'; /* Character indicating presence of following variable/dimension/attribute/group in file is optional */
@@ -131,6 +131,7 @@ main(int argc,char **argv)
   extern int optind;
 
   int abb_arg_nbr=0;
+  int fl_fmt; /* [enm] Output (and input) file format */
   int fl_nbr=0;
   int mch_nbr_att=0; /* [nbr] Number of renamed attributes */
   int mch_nbr_var=0; /* [nbr] Number of renamed variables */
@@ -361,7 +362,10 @@ main(int argc,char **argv)
   /* Open file enabled for writing. Place file in define mode for renaming. */
   if(RAM_OPEN) md_open=NC_WRITE|NC_DISKLESS; else md_open=NC_WRITE;
   rcd+=nco_fl_open(fl_out,md_open,&bfr_sz_hnt,&nc_id);
-  (void)nco_redef(nc_id);
+
+  /* 20141010: Avoid nc_rename_var/dim() bug */
+  (void)nco_inq_format(nc_id,&fl_fmt);
+  if(fl_fmt != NC_FORMAT_NETCDF4) rcd+=nco_redef(nc_id);
 
   /* Timestamp end of metadata setup and disk layout */
   rcd+=nco_ddra((char *)NULL,(char *)NULL,&ddra_info);
@@ -371,7 +375,7 @@ main(int argc,char **argv)
   trv_tbl_init(&trv_tbl); 
 
   /* Construct GTT (Group Traversal Table), check -v and -g input names and create extraction list*/
-  (void)nco_bld_trv_tbl(nc_id,trv_pth,(int)0,NULL,(int)0,NULL,False,False,NULL,(int)0,NULL,(int) 0,False,False,False,False,True,nco_pck_plc_nil,NULL,trv_tbl);
+  (void)nco_bld_trv_tbl(nc_id,trv_pth,(int)0,NULL,(int)0,NULL,False,False,NULL,(int)0,NULL,(int)0,False,False,False,False,True,nco_pck_plc_nil,NULL,trv_tbl);
 
   /* Rename variables */
   for(int idx_var=0;idx_var<nbr_var_rnm;idx_var++){
@@ -390,9 +394,9 @@ main(int argc,char **argv)
       if(trv_tbl->lst[tbl_idx].nco_typ == nco_obj_typ_var)
 	if(!strcmp(var_rnm_lst[idx_var].old_nm+mch_fst,trv_tbl->lst[tbl_idx].nm_fll) || !strcmp(var_rnm_lst[idx_var].old_nm+mch_fst,trv_tbl->lst[tbl_idx].nm)){
 	    mch_nbr++;
-	    (void)nco_inq_grp_full_ncid(nc_id,trv_tbl->lst[tbl_idx].grp_nm_fll,&grp_id);
-	    rcd=nco_inq_varid(grp_id,trv_tbl->lst[tbl_idx].nm,&var_rnm_lst[idx_var].id);
-	    (void)nco_rename_var(grp_id,var_rnm_lst[idx_var].id,var_rnm_lst[idx_var].new_nm);
+	    rcd+=nco_inq_grp_full_ncid(nc_id,trv_tbl->lst[tbl_idx].grp_nm_fll,&grp_id);
+	    rcd+=nco_inq_varid(grp_id,trv_tbl->lst[tbl_idx].nm,&var_rnm_lst[idx_var].id);
+	    rcd+=nco_rename_var(grp_id,var_rnm_lst[idx_var].id,var_rnm_lst[idx_var].new_nm);
 	    if(nco_dbg_lvl >= nco_dbg_fl) (void)fprintf(stdout,"%s: Renamed variable \'%s\' to \'%s\'\n",nco_prg_nm,trv_tbl->lst[tbl_idx].nm_fll,var_rnm_lst[idx_var].new_nm);
 	} /* endif */
 
@@ -614,16 +618,19 @@ main(int argc,char **argv)
   (void)omp_in_parallel();
 #endif /* !_OPENMP */
 
-  /* Take output file out of define mode */
-  if(hdr_pad == 0UL){
-    (void)nco_enddef(nc_id);
-  }else{
-    (void)nco__enddef(nc_id,hdr_pad);
-    if(nco_dbg_lvl >= nco_dbg_scl) (void)fprintf(stderr,"%s: INFO Padding header with %lu extra bytes\n",nco_prg_nm_get(),(unsigned long)hdr_pad);
-  } /* hdr_pad */
+  /* 20141010: Avoid nc_rename_var/dim() bug */
+  if(fl_fmt != NC_FORMAT_NETCDF4){
+    /* Take output file out of define mode */
+    if(hdr_pad == 0UL){
+      rcd+=nco_enddef(nc_id);
+    }else{
+      rcd+=nco__enddef(nc_id,hdr_pad);
+      if(nco_dbg_lvl >= nco_dbg_scl) (void)fprintf(stderr,"%s: INFO Padding header with %lu extra bytes\n",nco_prg_nm_get(),(unsigned long)hdr_pad);
+    } /* hdr_pad */
+  } /* NC_FORMAT_NETCDF4 */
 
   /* Close the open netCDF file */
-  nco_close(nc_id);
+  rcd+=nco_close(nc_id);
 
   /* Remove local copy of file */
   if(FL_RTR_RMT_LCN && RM_RMT_FL_PST_PRC) (void)nco_fl_rm(fl_in);
